#
# spec file for package python-mutagen
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%{!?py_ver %global py_ver %(python -c "import sys; v=sys.version_info[:2]; print '%%d.%%d'%%v" 2>/dev/null || echo PYTHON-NOT-FOUND)}

Name:           python-mutagen
Version:        1.22
Release:        5.2
Summary:        Python module to Handle Audio Metadata
License:        GPL-2.0
Group:          Development/Libraries/Python
Url:            https://pypi.python.org/pypi/mutagen
Source:         https://pypi.python.org/packages/source/m/mutagen/mutagen-%{version}.tar.gz
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Requires(post):	update-alternatives
Requires(postun): update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1110
BuildArch:      noarch
%endif

%description
Mutagen is a Python module to handle audio metadata. It supports FLAC,
M4A, MP3, Ogg FLAC, Ogg Speex, Ogg Theora, Ogg Vorbis, True Audio, and
WavPack audio files. All versions of ID3v2 are supported, and all
standard ID3v2.4 frames are parsed. It can read Xing headers to
accurately calculate the bitrate and length of MP3s. ID3 and APEv2 tags
can be edited regardless of their audio format. It can also manipulate
Ogg streams on an individual packet/page level.

%prep
%setup -q -n mutagen-%{version}
# remove shebangs from library files
find mutagen/ -name "*.py" -exec sed -i -e  '/^#!\s\?\/usr\/bin\/\(env\s\)\?python$/d' {} ';'

for i in `ls tools` ; do
	mv tools/${i} tools/${i}-%{py_ver}
done
for i in `ls man | sed "s/\.1//"` ; do
	mv man/${i}.1 man/${i}-%{py_ver}.1
done

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --prefix="%{_prefix}" 
ln -sf %{_bindir}/mid3iconv-%{py_ver} %{buildroot}%{_bindir}/mid3iconv
ln -sf %{_bindir}/mid3v2-%{py_ver} %{buildroot}%{_bindir}/mid3v2
ln -sf %{_bindir}/moggsplit-%{py_ver} %{buildroot}%{_bindir}/moggsplit
ln -sf %{_bindir}/mutagen-inspect-%{py_ver} %{buildroot}%{_bindir}/mutagen-inspect
ln -sf %{_bindir}/mutagen-pony-%{py_ver} %{buildroot}%{_bindir}/mutagen-pony

ln -sf %{_mandir}/man1/mid3iconv-%{py_ver}.1.gz %{buildroot}%{_mandir}/man1/mid3iconv.1.gz
ln -sf %{_mandir}/man1/mid3v2-%{py_ver}.1.gz %{buildroot}%{_mandir}/man1/mid3v2.1.gz
ln -sf %{_mandir}/man1/moggsplit-%{py_ver}.1.gz %{buildroot}%{_mandir}/man1/moggsplit.1.gz
ln -sf %{_mandir}/man1/mutagen-inspect-%{py_ver}.1.gz %{buildroot}%{_mandir}/man1/mutagen-inspect.1.gz
ln -sf %{_mandir}/man1/mutagen-pony-%{py_ver}.1.gz %{buildroot}%{_mandir}/man1/mutagen-pony.1.gz

%pre
# Since binaries became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[[ ! -L %{_bindir}/mid3iconv ]] && rm -f %{_bindir}/mid3iconv
[[ ! -L %{_bindir}/mid3v2 ]] && rm -f %{_bindir}/mid3v2  
[[ ! -L %{_bindir}/moggsplit ]] && rm -f %{_bindir}/moggsplit
[[ ! -L %{_bindir}/mutagen-inspect ]] && rm -f %{_bindir}/mutagen-inspect
[[ ! -L %{_bindir}/mutagen-pony ]] && rm -f %{_bindir}/mutagen-pony
[[ ! -L %{_mandir}/man1/mid3iconv.1.gz ]] && rm -f %{_mandir}/man1/mid3iconv.1.gz
[[ ! -L %{_mandir}/man1/mid3v2.1.gz ]] && rm -f %{_mandir}/man1/mid3v2.1.gz
[[ ! -L %{_mandir}/man1/moggsplit.1.gz ]] && rm -f %{_mandir}/man1/moggsplit.1.gz
[[ ! -L %{_mandir}/man1/mutagen-inspect.1.gz ]] && rm -f %{_mandir}/man1/mutagen-inspect.1.gz
[[ ! -L %{_mandir}/man1/mutagen-pony.1.gz ]] && rm -f %{_mandir}/man1/mutagen-pony.1.gz

exit 0

%post
update-alternatives \
--install %{_bindir}/mid3iconv mid3iconv %{_bindir}/mid3iconv-%{py_ver} 30 \
--slave %{_bindir}/mid3v2 mid3v2 %{_bindir}/mid3v2-%{py_ver} \
--slave %{_bindir}/moggsplit moggsplit %{_bindir}/moggsplit-%{py_ver} \
--slave %{_bindir}/mutagen-inspect mutagen-inspect %{_bindir}/mutagen-inspect-%{py_ver} \
--slave %{_bindir}/mutagen-pony mutagen-pony %{_bindir}/mutagen-pony-%{py_ver} \
--slave %{_mandir}/man1/mid3iconv.1.gz mid3iconv.1.gz %{_mandir}/man1/mid3iconv-%{py_ver}.1.gz \
--slave %{_mandir}/man1/mid3v2.1.gz mid3v2.1.gz %{_mandir}/man1/mid3v2-%{py_ver}.1.gz \
--slave %{_mandir}/man1/moggsplit.1.gz moggsplit.1.gz %{_mandir}/man1/moggsplit-%{py_ver}.1.gz \
--slave %{_mandir}/man1/mutagen-inspect.1.gz mutagen-inspect.1.gz %{_mandir}/man1/mutagen-inspect-%{py_ver}.1.gz \
--slave %{_mandir}/man1/mutagen-pony.1.gz mutagen-pony.1.gz %{_mandir}/man1/mutagen-pony-%{py_ver}.1.gz

%preun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove mid3iconv %{_bindir}/mid3iconv-%{py_ver}
fi

%files
%defattr(-, root, root, 0755)
%doc COPYING NEWS README TODO
%ghost %{_bindir}/mid3iconv
%{_bindir}/mid3iconv-%{py_ver}
%ghost %{_bindir}/mid3v2
%{_bindir}/mid3v2-%{py_ver}
%ghost %{_bindir}/moggsplit
%{_bindir}/moggsplit-%{py_ver}
%ghost %{_bindir}/mutagen-inspect
%{_bindir}/mutagen-inspect-%{py_ver}
%ghost %{_bindir}/mutagen-pony
%{_bindir}/mutagen-pony-%{py_ver}
%{python_sitelib}/mutagen
%{python_sitelib}/mutagen-%{version}-py%{py_ver}.egg-info
%ghost %{_mandir}/man1/mid3iconv.1.gz
%{_mandir}/man1/mid3iconv-%{py_ver}.1.gz
%ghost %{_mandir}/man1/mid3v2.1.gz
%{_mandir}/man1/mid3v2-%{py_ver}.1.gz
%ghost %{_mandir}/man1/moggsplit.1.gz
%{_mandir}/man1/moggsplit-%{py_ver}.1.gz
%ghost %{_mandir}/man1/mutagen-inspect.1.gz
%{_mandir}/man1/mutagen-inspect-%{py_ver}.1.gz
%ghost %{_mandir}/man1/mutagen-pony.1.gz
%{_mandir}/man1/mutagen-pony-%{py_ver}.1.gz

%changelog
* Mon Oct 14 2013 i@marguerite.su
- Implement update-alternatives
  * prepare for python3-mutagenx, which has the same binaries/manpages
    as this one but still in python2 state.
  * it just doesn't hurt...
* Sun Oct 13 2013 p.drouand@gmail.com
- Replace python-distribute with python-setuptools BuildRequires
- Remove Requires: python = %%{py_ver}; it's useless
* Sat Oct 12 2013 i@marguerite.su
- update to 1.22:
  * Minimum required Python version is now 2.6
  * Online API reference at https://mutagen.readthedocs.org/
  * EasyID3:
  * Fix crash with empty TXXX values. (#135)
  * ID3:
  * id3v2.3 writing support (#85)
  * Add iTunes podcast frames (TGID, TDES, WFED) (#141)
  * Updated id3v1 genre list
  * MP4:
  * add_tags() will not replace existing tags. (#101)
  * Don't ignore tags if parsing unknown atoms fails.
  * Raise on invalid 64bit atom size (#132, Sidnei da Silva)
  * APEv2:
  * Handle invalid tag item count. (#145, Dawid Zamirski)
  * Ogg:
  * Faster parsing of files with large packets.
  * VComment:
  * Preserve text case for field names added through the dict interface (#152)
  * mid3v2:
  * New -e,--escape switch to enable interpretation of escape sequences and
    makes escaping of the colon separator possible. (#159)
  * mid3iconv:
  * Convert COMM frames (#128)
- clean spec and don't use the INSTALLED_FILES way, which make this spec
  contains no useful information exposed on web
  * expand %%py_requires or SP1 won't build
  * add BuildRequires: python-distrubite because it used setup.py
  * remove the entire %%clean section, unneeded now
  * TUTORIAL is no more, so no need of dos2unix too.
* Tue Oct 26 2010 boris@steki.net
- spec file fixes
  * fixed suse version for OS11.2 as it have noarch detected correctly
  * remove shebangs from library files
  * simplified fix for compressed manual pages
* Tue Sep 14 2010 coolo@novell.com
- update to 1.20:
  * tons of changes in two years time, support for almost everything
    improved, see NEWS file for a lengthy description
* Tue Jun 24 2008 dmueller@suse.de
- update to 1.14:
  * MP4/M4A: Fixed saving of atoms with 64-bit size on 64-bit platforms.
  * MP4: Conversion of 'gnre' atoms to '\xa9gen' text atoms now correctly
    produces a list of string values, not just a single value.
  * ID3: Broken RVA2 frames are now discarded. (Vladislav Naumov)
  * ID3: Use long integers when appropriate.
  * VCommentDict: Raise UnicodeEncodeErrors when trying to use a Unicode
    key that is not valid ASCII; keys are also normalized to ASCII
    str objects. (Forest Bond)
* Wed Jan 16 2008 hvogel@suse.de
- Update to version 1.13
  * FLAC: Raise IOError, instead of UnboundLocalError, when trying
    to open a non-existant file. (Lukáš Lalinský, Debian #448734)
  * Throw out invalid frames when upgrading from 2.3 to 2.4.
  * Fixed reading of Unicode strings from ASF files on big-endian
  platforms.
  * TCP/TCMP support.
  * Faster implementation of file-writing when mmap fails, and
  exclusive advisory locking when available.
  * Use VBRI header to calculate length of VBR MP3 files if the Xing
  header is not found.
  * Write important ID3v2 frames near the start. (Lukáš Lalinský)
* Wed Jul  4 2007 hvogel@suse.de
- Initial package, Version 1.11
